pub struct DiskUsageSensor { /* private fields */ }Expand description
Sensor that reads disk usage percentage for a given mount point.
Uses statvfs to determine the fraction of used space.
Returns a value in [0.0, 100.0].
Implementations